@@ -10,6 +10,9 @@ pub use network::VPCSpec;
 pub use tags::Tags;
 pub use types::AZSelectionScheme;
 pub use types::Instance;
+pub use types::InstanceState;
+pub use types::Volume;
+pub use types::VolumeType;
 
 mod impls;
 mod machine;
