@@ -40,7 +40,8 @@ pub struct AWSMachineTemplateResource {
     group = "infrastructure.cluster.x-k8s.io",
     version = "v1beta1",
     kind = "AWSMachine",
-    plural = "awsmachines"
+    plural = "awsmachines",
+    status = "AWSMachineStatus"
 )]
 #[kube(namespaced)]
 #[kube(schema = "disabled")]
@@ -126,12 +127,12 @@ pub struct AWSMachineSpec {
 
     /// RootVolume encapsulates the configuration options for the root volume
     // +optional
-    // pub root_volume: Option<Volume>, //`json:"rootVolume,omitempty"`
+    pub root_volume: Option<Volume>, //`json:"rootVolume,omitempty"`
 
     /// Configuration options for the non root storage volumes.
     // +optional
-    // #[serde(default, skip_serializing_if = "Vec::is_empty")]
-    // pub non_root_volumes: Vec<Volume>, //`json:"nonRootVolumes,omitempty"`
+    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    pub non_root_volumes: Vec<Volume>, //`json:"nonRootVolumes,omitempty"`
 
     /// NetworkInterfaces is a list of ENIs to associate with the instance.
     /// A maximum of 2 may be specified.
@@ -160,6 +161,71 @@ pub struct AWSMachineSpec {
     pub tenancy: Option<String>, //`json:"tenancy,omitempty"`
 }
 
+/// AWSMachineStatus defines the observed state of AWSMachine.
+#[skip_serializing_none]
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
+#[serde(rename_all = "camelCase")]
+pub struct AWSMachineStatus {
+    /// Ready is true when the provider resource is ready.
+    // +optional
+    pub ready: Option<bool>, // `json:"ready"`
+
+    /// Interruptible reports that this machine is using spot instances and can therefore be interrupted by CAPI when it receives a notice that the spot instance is to be terminated by AWS.
+    /// This will be set to true when SpotMarketOptions is not nil (i.e. this machine is using a spot instance).
+    // +optional
+    pub interruptible: Option<bool>, // `json:"interruptible,omitempty"`
+
+    /// Addresses contains the AWS instance associated addresses.
+    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    pub addresses: Vec<clusterv1::MachineAddress>, // `json:"addresses,omitempty"`
+
+    /// InstanceState is the state of the AWS instance for this machine.
+    // +optional
+    pub instance_state: Option<InstanceState>, // `json:"instanceState,omitempty"`
+
+    /// FailureReason will be set in the event that there is a terminal problem
+    /// reconciling the Machine and will contain a succinct value suitable
+    /// for machine interpretation.
+    ///
+    /// This field should not be set for transitive errors that a controller
+    /// faces that are expected to be fixed automatically over
+    /// time (like service outages), but instead indicate that something is
+    /// fundamentally wrong with the Machine's spec or the configuration of
+    /// the controller, and that manual intervention is required. Examples
+    /// of terminal errors would be invalid combinations of settings in the
+    /// spec, values that are unsupported by the controller, or the
+    /// responsible controller itself being critically misconfigured.
+    ///
+    /// Any transient errors that occur during the reconciliation of Machines
+    /// can be added as events to the Machine object and/or logged in the
+    /// controller's output.
+    // +optional
+    pub failure_reason: Option<errors::MachineStatusError>, // `json:"failureReason,omitempty"`
+
+    /// FailureMessage will be set in the event that there is a terminal problem
+    /// reconciling the Machine and will contain a more verbose string suitable
+    /// for logging and human consumption.
+    ///
+    /// This field should not be set for transitive errors that a controller
+    /// faces that are expected to be fixed automatically over
+    /// time (like service outages), but instead indicate that something is
+    /// fundamentally wrong with the Machine's spec or the configuration of
+    /// the controller, and that manual intervention is required. Examples
+    /// of terminal errors would be invalid combinations of settings in the
+    /// spec, values that are unsupported by the controller, or the
+    /// responsible controller itself being critically misconfigured.
+    ///
+    /// Any transient errors that occur during the reconciliation of Machines
+    /// can be added as events to the Machine object and/or logged in the
+    /// controller's output.
+    // +optional
+    pub failure_message: Option<String>, // `json:"failureMessage,omitempty"`
+
+    /// Conditions defines current service state of the AWSMachine.
+    // +optional
+    pub conditions: Option<clusterv1::Conditions>, // `json:"conditions,omitempty"`
+}
+
 // package v1beta1
 
 // import (
@@ -212,67 +278,6 @@ pub struct AWSMachineSpec {
 // 	SecureSecretsBackend SecretBackend `json:"secureSecretsBackend,omitempty"`
 // }
 
-// // AWSMachineStatus defines the observed state of AWSMachine.
-// type AWSMachineStatus struct {
-// 	// Ready is true when the provider resource is ready.
-// 	// +optional
-// 	Ready bool `json:"ready"`
-
-// 	// Interruptible reports that this machine is using spot instances and can therefore be interrupted by CAPI when it receives a notice that the spot instance is to be terminated by AWS.
-// 	// This will be set to true when SpotMarketOptions is not nil (i.e. this machine is using a spot instance).
-// 	// +optional
-// 	Interruptible bool `json:"interruptible,omitempty"`
-
-// 	// Addresses contains the AWS instance associated addresses.
-// 	Addresses []clusterv1.MachineAddress `json:"addresses,omitempty"`
-
-// 	// InstanceState is the state of the AWS instance for this machine.
-// 	// +optional
-// 	InstanceState *InstanceState `json:"instanceState,omitempty"`
-
-// 	// FailureReason will be set in the event that there is a terminal problem
-// 	// reconciling the Machine and will contain a succinct value suitable
-// 	// for machine interpretation.
-// 	//
-// 	// This field should not be set for transitive errors that a controller
-// 	// faces that are expected to be fixed automatically over
-// 	// time (like service outages), but instead indicate that something is
-// 	// fundamentally wrong with the Machine's spec or the configuration of
-// 	// the controller, and that manual intervention is required. Examples
-// 	// of terminal errors would be invalid combinations of settings in the
-// 	// spec, values that are unsupported by the controller, or the
-// 	// responsible controller itself being critically misconfigured.
-// 	//
-// 	// Any transient errors that occur during the reconciliation of Machines
-// 	// can be added as events to the Machine object and/or logged in the
-// 	// controller's output.
-// 	// +optional
-// 	FailureReason *errors.MachineStatusError `json:"failureReason,omitempty"`
-
-// 	// FailureMessage will be set in the event that there is a terminal problem
-// 	// reconciling the Machine and will contain a more verbose string suitable
-// 	// for logging and human consumption.
-// 	//
-// 	// This field should not be set for transitive errors that a controller
-// 	// faces that are expected to be fixed automatically over
-// 	// time (like service outages), but instead indicate that something is
-// 	// fundamentally wrong with the Machine's spec or the configuration of
-// 	// the controller, and that manual intervention is required. Examples
-// 	// of terminal errors would be invalid combinations of settings in the
-// 	// spec, values that are unsupported by the controller, or the
-// 	// responsible controller itself being critically misconfigured.
-// 	//
-// 	// Any transient errors that occur during the reconciliation of Machines
-// 	// can be added as events to the Machine object and/or logged in the
-// 	// controller's output.
-// 	// +optional
-// 	FailureMessage *string `json:"failureMessage,omitempty"`
-
-// 	// Conditions defines current service state of the AWSMachine.
-// 	// +optional
-// 	Conditions clusterv1.Conditions `json:"conditions,omitempty"`
-// }
-
 // // +kubebuilder:object:root=true
 // // +kubebuilder:resource:path=awsmachines,scope=Namespaced,categories=cluster-api,shortName=awsm
 // // +kubebuilder:storageversion
