@@ -53,6 +53,24 @@ impl AWSMachineTemplate {
         self
     }
 
+    #[must_use]
+    pub fn root_volume(mut self, root_volume: Volume) -> Self {
+        self.spec.template.spec.root_volume = Some(root_volume);
+        self
+    }
+
+    #[must_use]
+    pub fn root_volume_size(self, size: i64) -> Self {
+        let root_volume = Volume::gp3(size);
+        self.root_volume(root_volume)
+    }
+
+    #[must_use]
+    pub fn non_root_volumes(mut self, volumes: Vec<Volume>) -> Self {
+        self.spec.template.spec.non_root_volumes = volumes;
+        self
+    }
+
     #[must_use]
     pub fn namespace(self, namespace: &str) -> Self {
         Self {
